@@ -258,9 +258,10 @@ int CCBO::ctcl_lunar_month(int y,int m,int d)
 
   return lunar_month;  
 }
-QString CCBO::ctcl_displaydata(int y, int m, int d,QString data)
+QString CCBO::ctcl_displaydata(int y, int m, int d)
 {
     QString QueryStr;
+    QString data;
     QueryStr=QString("select note from cnote where y=%1 and m=%2 and d=%3").arg(y).arg(m).arg(d);
     data=ctcl_common_query("cnote",QueryStr);
     return data;
@@ -274,7 +275,7 @@ int CCBO::ctcl_savenote(int  y,int m, int d ,QString textedit)
     QString note;
     QString insert;
     QueryStr=QString("select note from cnote where y=%1 and m=%2 and d=%3").arg(y).arg(m).arg(d);
-    note=ctcl_common_query("cnote",QueryStr);    
+    note=ctcl_common_query("cnote",QueryStr);
     if(textedit.isEmpty()&&note.isEmpty())
         return 0;
     if(note.isEmpty())
@@ -410,13 +411,45 @@ int CCBO::ctcl_solar_to_lunar(int y,int m,int d,struct CCalendar* ctc)
     ctc->choliday=ctcl_common_query("choliday",QueryStr);
     //logSqlError("choliday",QueryStr);
     }
+   if(ctc->month>0&&!(ctc->choliday.isEmpty()))
+       ctc->ischoliday=true;
+   else
+       ctc->ischoliday=false;
   return 1;
 }
 
 bool CCBO::InitConnection(QString Path)
 {
+    QString QueryStr;
+    QString systempath,systemdirectory;
+    QStringList env = QProcess::systemEnvironment().filter(QRegExp("^XDG_DATA_HOME="));
+    if (env.length() == 0) {
+        systemdirectory = QDir::homePath() + "/.local/share";
+    } else {
+        systemdirectory = env.at(0);
+        systemdirectory = systemdirectory.mid(systemdirectory.indexOf("=") + 1);
+        if (systemdirectory.isEmpty()) {
+            systemdirectory = QDir::homePath() + "/.local/share";
+        }
+    }
+
+    systemdirectory = QString("%1/chinese-calendar").arg(systemdirectory);
+    systempath = QString("%1/KylinLunar.db").arg(systemdirectory);
+
+    if(!QFile::exists(systempath))
+    {
+        QDir d;
+        if (d.mkpath(systemdirectory) == false) {
+            return false;
+        }
+        if (QFile::copy("/usr/share/chinese-calendar/db/KylinLunar.db", systempath) == false) {
+            return false;
+        }
+    }
+
     QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("/usr/share/chinese-calendar/db/KylinLunar.db");
+    db.setDatabaseName(systempath);
+
     if (!db.open()) {
             return false;
     }
