@@ -65,6 +65,7 @@ struct CCalendar
     QString holiday;
     QString choliday;
     bool laststerm;
+    bool ischoliday;
     QString yi;
     QString ji;
     QString note;
@@ -78,7 +79,7 @@ public:
     int ctcl_solar_to_lunar(int y,int m,int d,struct CCalendar* ctc);
     bool InitConnection(QString Path);
     int ctcl_savenote(int  y,int m, int d ,QString textedit);
-    QString ctcl_displaydata(int y,int m,int d,QString data);
+    QString ctcl_displaydata(int y,int m,int d);
 private:
     QByteArray lunarstr;
     int maxyear;
