@@ -21,14 +21,13 @@
  */
 
 #include "chinesecalendar.h"
-
+#include <QSettings>
 
 ChineseCalendar::ChineseCalendar(QWidget *parent)
     : QWidget(parent)
 {
-    setupUi(this);
-
-    bg = new QPixmap(":/img/chinesecalendarBGblue.png");
+    setupUi(this); m_strFileList.clear();
+//    bg = new QPixmap(":/img/chinesecalendarBGyellow.png");
     icon = QIcon(":/img/icon.png");
     icon64 = QIcon(":/img/chinesecalendar-64.png");
     mycalendat=new CCBO;
@@ -41,16 +40,15 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     connect(YearSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setYear(int)));
     connect(this->backtotoday, SIGNAL(clicked()), this, SLOT(backtoday()));
 
-
-    this->TbnextMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->TbnextYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->TbpreviousMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->TbpreviousYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->backtotoday->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->YearSelect->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
-    this->monthCombo->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
-    this->label->setStyleSheet("QLabel{font:12pt;}");
-    this->label_2->setStyleSheet("QLabel{font:12pt;}");
+//    this->TbnextMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
+//    this->TbnextYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
+//    this->TbpreviousMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
+//    this->TbpreviousYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
+//    this->backtotoday->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
+//    this->YearSelect->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
+//    this->monthCombo->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
+//    this->label->setStyleSheet("QLabel{font:12pt;}");
+//    this->label_2->setStyleSheet("QLabel{font:12pt;}");
 
     QDateTime dateTime;
     QString currentTime;
@@ -187,222 +185,259 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     map->insert(QString("1-1"), dateitem00 );
     connect(dateitem00, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem00, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem00, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem01 = new DateItem(this);
     dateitem01->show();
     map->insert(QString("1-2"), dateitem01 );
     connect(dateitem01, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem01, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem01, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem02 = new DateItem(this);
     dateitem02->show();
     map->insert(QString("1-3"), dateitem02 );
     connect(dateitem02, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem02, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem02, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem03 = new DateItem(this);
     dateitem03->show();
     map->insert(QString("1-4"), dateitem03 );
     connect(dateitem03, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem03, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem03, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem04 = new DateItem(this);
     dateitem04->show();
     map->insert(QString("1-5"), dateitem04 );
     connect(dateitem04, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem04, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem04, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem05 = new DateItem(this);
     dateitem05->show();
     map->insert(QString("1-6"), dateitem05 );
     connect(dateitem05, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem05, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem05, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem06 = new DateItem(this);
     dateitem06->show();
     map->insert(QString("1-7"), dateitem06 );
     connect(dateitem06, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem06, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem06, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem10 = new DateItem(this);
     dateitem10->show();
     map->insert(QString("2-1"), dateitem10 );
     connect(dateitem10, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem10, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem10, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem11 = new DateItem(this);
     dateitem11->show();
     map->insert(QString("2-2"), dateitem11 );
     connect(dateitem11, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem11, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem11, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem12 = new DateItem(this);
     dateitem12->show();
     map->insert(QString("2-3"), dateitem12 );
     connect(dateitem12, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem12, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem12, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem13 = new DateItem(this);
     dateitem13->show();
     map->insert(QString("2-4"), dateitem13 );
     connect(dateitem13, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem13, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem13, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem14 = new DateItem(this);
     dateitem14->show();
     map->insert(QString("2-5"), dateitem14 );
     connect(dateitem14, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem14, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem14, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem15 = new DateItem(this);
     dateitem15->show();
     map->insert(QString("2-6"), dateitem15 );
     connect(dateitem15, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem15, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem15, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem16 = new DateItem(this);
     dateitem16->show();
     map->insert(QString("2-7"), dateitem16 );
     connect(dateitem16, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem16, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem16, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem20 = new DateItem(this);
     dateitem20->show();
     map->insert(QString("3-1"), dateitem20 );
     connect(dateitem20, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem20, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem20, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem21 = new DateItem(this);
     dateitem21->show();
     map->insert(QString("3-2"), dateitem21 );
     connect(dateitem21, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem21, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem21, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem22 = new DateItem(this);
     dateitem22->show();
     map->insert(QString("3-3"), dateitem22 );
     connect(dateitem22, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem22, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem22, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem23 = new DateItem(this);
     dateitem23->show();
     map->insert(QString("3-4"), dateitem23 );
     connect(dateitem23, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem23, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem23, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem24 = new DateItem(this);
     dateitem24->show();
     map->insert(QString("3-5"), dateitem24 );
     connect(dateitem24, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem24, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem24, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem25 = new DateItem(this);
     dateitem25->show();
     map->insert(QString("3-6"), dateitem25 );
     connect(dateitem25, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem25, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem25, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem26 = new DateItem(this);
     dateitem26->show();
     map->insert(QString("3-7"), dateitem26 );
     connect(dateitem26, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem26, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem26, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem30 = new DateItem(this);
     dateitem30->show();
     map->insert(QString("4-1"), dateitem30 );
     connect(dateitem30, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem30, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem30, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem31 = new DateItem(this);
     dateitem31->show();
     map->insert(QString("4-2"), dateitem31 );
     connect(dateitem31, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem31, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem31, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem32 = new DateItem(this);
     dateitem32->show();
     map->insert(QString("4-3"), dateitem32 );
     connect(dateitem32, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem32, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem32, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem33 = new DateItem(this);
     dateitem33->show();
     map->insert(QString("4-4"), dateitem33 );
     connect(dateitem33, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem33, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem33, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem34 = new DateItem(this);
     dateitem34->show();
     map->insert(QString("4-5"), dateitem34 );
     connect(dateitem34, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem34, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem34, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem35 = new DateItem(this);
     dateitem35->show();
     map->insert(QString("4-6"), dateitem35 );
     connect(dateitem35, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem35, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem35, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem36 = new DateItem(this);
     dateitem36->show();
     map->insert(QString("4-7"), dateitem36 );
     connect(dateitem36, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem36, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem36, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem40 = new DateItem(this);
     dateitem40->show();
     map->insert(QString("5-1"), dateitem40 );
     connect(dateitem40, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem40, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem40, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem41 = new DateItem(this);
     dateitem41->show();
     map->insert(QString("5-2"), dateitem41 );
     connect(dateitem41, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem41, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem41, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem42 = new DateItem(this);
     dateitem42->show();
     map->insert(QString("5-3"), dateitem42 );
     connect(dateitem42, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem42, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem42, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem43 = new DateItem(this);
     dateitem43->show();
     map->insert(QString("5-4"), dateitem43 );
     connect(dateitem43, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem43, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem43, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem44 = new DateItem(this);
     dateitem44->show();
     map->insert(QString("5-5"), dateitem44 );
     connect(dateitem44, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem44, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem44, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem45 = new DateItem(this);
     dateitem45->show();
     map->insert(QString("5-6"), dateitem45 );
     connect(dateitem45, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem45, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem45, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem46 = new DateItem(this);
     dateitem46->show();
     map->insert(QString("5-7"), dateitem46 );
     connect(dateitem46, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem46, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem46, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem50 = new DateItem(this);
     dateitem50->hide();
     map->insert(QString("6-1"), dateitem50 );
     connect(dateitem50, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem50, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem50, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem51 = new DateItem(this);
     dateitem51->hide();
     map->insert(QString("6-2"), dateitem51 );
     connect(dateitem51, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
     connect(dateitem51, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
+    connect(dateitem51, SIGNAL(resetColor()), this, SLOT(resetDateItemColor()));
 
     DateItem *dateitem52 = new DateItem(this);
     dateitem52->hide();
@@ -439,17 +474,17 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     painter.drawRoundedRect(this->rect(),10,10);
     setMask(objBitmap);
 
+    aboutDlg = new AboutDialog();
+    aboutDlg->hide();
 
     this->createTray();
 
-
     note = new Cnote;
     QDesktopWidget desktop;
     int width = desktop.screenGeometry().width();
     note->setGeometry(QRect(width-400,80,224,280));
     connect(note,SIGNAL(save(QString)),this,SLOT(savedata(QString)));
     note->hide();
-
 }
 
 ChineseCalendar::~ChineseCalendar()
@@ -463,6 +498,7 @@ void ChineseCalendar::setclickday(QString day)
     int year = this->YearSelect->currentText().toInt();
     int month = this->monthCombo->currentText().toInt();
     int today = clickday;
+    selectedDate = QDate(year, month, today);
     QString dateplan = QString("%1月%2日计划安排").arg(this->monthCombo->currentText()).arg(day);
     QString data;
     data=mycalendat->ctcl_displaydata(year,month,today);
@@ -486,34 +522,90 @@ void ChineseCalendar::createTray()
 {
     this->actionShow = new QAction(tr("隐藏/显示"), this);
     connect(actionShow, SIGNAL(triggered()), this, SLOT(showOrHide()));
+    QShortcut *shortcut = new QShortcut(QKeySequence("Ctrl+H"), this);
+    connect(shortcut, SIGNAL(activated()), this, SLOT(showOrHide()));
+
+    this->actionAutoStart = new QAction(tr("AutoStart"), this);
+    this->actionAutoStart->setCheckable(true);
+    connect(actionAutoStart, SIGNAL(triggered(bool)), this, SLOT(setAutoStart(bool)));
 
     this->actionStaysOnTop = new QAction(tr("总在最前"), this);
     this->actionStaysOnTop->setCheckable(true);
-    connect(actionStaysOnTop, SIGNAL(triggered()), this, SLOT(setMode()));
+    connect(actionStaysOnTop, SIGNAL(triggered()), this, SLOT(slotChangeMode()));
 
     this->actionStaysOnBottom = new QAction(tr("总在最后"), this);
     this->actionStaysOnBottom->setCheckable(true);
-    connect(actionStaysOnBottom, SIGNAL(triggered()), this, SLOT(setMode()));
+    connect(actionStaysOnBottom, SIGNAL(triggered()), this, SLOT(slotChangeMode()));
 
     this->actionStaysNormal = new QAction(tr("普通模式"), this);
     this->actionStaysNormal->setCheckable(true);
     this->actionStaysNormal->setChecked(true);
-    connect(actionStaysNormal, SIGNAL(triggered()), this, SLOT(setMode()));
+    connect(actionStaysNormal, SIGNAL(triggered()), this, SLOT(slotChangeMode()));
+
+    // default skin
+    this->actionDefault = new QAction(tr("Default"), this);
+    actionDefault->setCheckable(true);
+    actionDefault->setChecked(true);
+    m_skinName = QString("default");
+    connect(actionDefault, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
+
+    // blue skin
+    this->actionSkin = new QAction(tr("Blue"), this);
+    actionSkin->setCheckable(true);
+    connect(actionSkin, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
+
+    this->skinMenu = new QMenu(tr("换肤"), this);
+    this->skinMenu->addAction(actionDefault);
+    this->skinMenu->addAction(actionSkin);
+
+    QActionGroup *actSkinGrp = new QActionGroup(this);
+    actSkinGrp->addAction(actionDefault);
+    actSkinGrp->addAction(actionSkin);
+
+    readSetting();
+    actionDefault->setChecked(m_skinName == "default");
+    actionSkin->setChecked(m_skinName == "blue");
+
+    // read user customizated skin files
+    readSkinFiles();
+
+    foreach (QString strSkin, m_strFileList)
+    {
+        QAction *actionNew = new QAction(strSkin, this);
+        actionNew->setCheckable(true);
+        actionNew->setChecked(m_skinName == strSkin);
+        actSkinGrp->addAction(actionNew);
+        this->skinMenu->addAction(actionNew);
+        connect(actionNew, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
+    }
 
     this->ag = new QActionGroup(this);
     this->ag->addAction(actionStaysOnTop);
     this->ag->addAction(actionStaysOnBottom);
     this->ag->addAction(actionStaysNormal);
 
-    this->actionQuit = new QAction(tr("退出程序"), this);
+    this->stayMenu = new QMenu(tr("Stay Mode"), this);
+    this->stayMenu->addAction(actionStaysOnTop);
+    this->stayMenu->addAction(actionStaysOnBottom);
+    this->stayMenu->addAction(actionStaysNormal);
+
+    this->actionAbout = new QAction(tr("关于本软件"), this);
+    connect(actionAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
+
+    this->actionQuit = new QAction(tr("E&xit"), this);
+    this->actionQuit->setShortcut(tr("Ctrl+Q"));
     connect(actionQuit, SIGNAL(triggered()), qApp, SLOT(quit()));
 
     this->trayMenu = new QMenu(this);
     this->trayMenu->addAction(actionShow);
     this->trayMenu->addSeparator();
-    this->trayMenu->addAction(actionStaysOnTop);
-    this->trayMenu->addAction(actionStaysOnBottom);
-    this->trayMenu->addAction(actionStaysNormal);
+    this->trayMenu->addAction(actionAutoStart);
+    this->trayMenu->addSeparator();
+    this->trayMenu->addMenu(stayMenu);
+    this->trayMenu->addSeparator();
+    this->trayMenu->addMenu(skinMenu);
+    this->trayMenu->addSeparator();
+    this->trayMenu->addAction(actionAbout);
     this->trayMenu->addSeparator();
     this->trayMenu->addAction(actionQuit);
 
@@ -526,8 +618,11 @@ void ChineseCalendar::createTray()
 
 void ChineseCalendar::paintEvent(QPaintEvent *)
 {
+    QStyleOption opt;
+    opt.init(this);
     QPainter painter(this);
-    painter.drawPixmap(0,0,width(),height(),*bg);
+//    painter.drawPixmap(0,0,width(),height(),*bg);
+    style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 
 //    painter.setPen(Qt::gray);
     painter.setPen(QColor(255,121,3,100));
@@ -751,6 +846,7 @@ void ChineseCalendar::resetcalendardate(QString day)
 {
     QDate date(this->YearSelect->currentText().toInt(),this->monthCombo->currentText().toInt(),day.toInt());
     clearbackground();
+    selectedDate = date;
     QString weekday;
     if(date.toString("ddd") == "Mon")
         weekday = "星期一";
@@ -857,11 +953,12 @@ void ChineseCalendar::backtoday()
     QDate today = QDate::currentDate();
     YearSelect->setCurrentIndex(today.year() - 1900);
     monthCombo->setCurrentIndex(today.month() - 1);
+    selectedDate = today;
     setCalendar();
 
 }
 
-void ChineseCalendar::setCalendar()
+void ChineseCalendar::setCalendar(bool flag)
 {
     struct CCalendar c;
     cleardate();
@@ -907,17 +1004,12 @@ void ChineseCalendar::setCalendar()
     } 
 
     QDate today = QDate::currentDate();
-    if(today.year() == selectedDate.year() && today.month() == selectedDate.month())
+    if(today.year() == selectedDate.year() && today.month() == selectedDate.month() && today.day() == selectedDate.day())
     {
-        int d = today.day();
-        int w = today.dayOfWeek();
-        if (w == 7)
-            w = 0;
-        int r = (d + (6 - w) + 7 -1)/7;
-        QString add = QString("%1-%2").arg(r).arg(w+1);
-        resetcalendardate(QString::number(today.day()));
-        map->value(add)->setToday();
+        setDayFocus(today);
     }
+
+    setDayFocus(selectedDate, false); // set the selected date in focus
 }
 
 void ChineseCalendar::clearbackground()
@@ -1172,19 +1264,237 @@ void ChineseCalendar::showOrHide()
         this->hide();
 }
 
-void ChineseCalendar::setMode()
+void ChineseCalendar::setMode(int nMode, bool bFlag)
 {
-    if(this->actionStaysOnTop->isChecked())
+    switch (nMode)
     {
+    case 1: // stays on top
         this->setWindowFlags(Qt::ToolTip | Qt::FramelessWindowHint);
-        this->show();
-    } else if(this->actionStaysOnBottom->isChecked())
-    {
+        break;
+    case 2: // stays on bottom
         this->setWindowFlags(Qt::WindowStaysOnBottomHint | Qt::FramelessWindowHint);
-        this->show();
-    } else
-    {
+        break;
+    case 3: // stays normal
         this->setWindowFlags(Qt::FramelessWindowHint);
+        break;
+    default:
+        break;
+    }
+
+    if (bFlag)
         this->show();
+}
+
+void ChineseCalendar::slotChangeSkin()
+{
+    QAction *action = qobject_cast<QAction *>(sender());
+    QString strSkin = action->text();
+
+    if (!strSkin.isEmpty())
+    {
+        if (strSkin.toLower() == "default" || strSkin.toLower() == "blue")
+        {
+            strSkin = strSkin.toLower();
+            changeSkin(strSkin);
+        }
+        else
+        {
+            changeSkin(strSkin, false);
+        }
+    }
+
+    m_skinName = strSkin;
+
+    setCalendar();
+
+    writeSetting();
+}
+
+void ChineseCalendar::slotChangeMode()
+{
+    m_nMode = 0;
+    if (actionStaysOnTop->isChecked())
+        m_nMode = 1;
+    if (actionStaysOnBottom->isChecked())
+        m_nMode = 2;
+    if (actionStaysNormal->isChecked())
+        m_nMode = 3;
+
+    setMode(m_nMode);
+
+    writeSetting();
+}
+
+void ChineseCalendar::changeSkin(const QString &skin, bool bFlag)
+{
+    QString strFilename("");
+
+    if (bFlag)
+    {
+#ifdef DEBUG
+        strFilename = QCoreApplication::applicationDirPath() + QString("/skin/%1-skin.qss").arg(skin);
+#else
+        strFilename = QString("/usr/share/chinese-calendar/skin/%1-skin.qss").arg(skin);
+#endif
+    }
+    else
+    {
+        strFilename =  QDir::homePath() + QString("/.local/share/chinese-calendar/skin/%1.qss").arg(skin);
+    }
+
+    QFile qss(strFilename);
+    if (qss.open(QFile::ReadOnly))
+    {
+        qApp->setStyleSheet(qss.readAll());
+        qss.close();
     }
 }
+
+void ChineseCalendar::readSkinFiles()
+{
+    QString systemdirectory;
+    systemdirectory = QDir::homePath() + "/.local/share/chinese-calendar/skin/";
+
+    QDir dir(systemdirectory);
+    foreach(QFileInfo info, dir.entryInfoList())
+    {
+        if (info.isFile() && info.suffix() == "qss")
+        {
+            m_strFileList << info.baseName();
+        }
+    }
+}
+
+void ChineseCalendar::resetDateItemColor()
+{
+    setCalendar(true);
+}
+
+void ChineseCalendar::setDayFocus(QDate &date, bool bFlag)
+{
+    int d = date.day();
+    int w = date.dayOfWeek();
+    if (w == 7)
+        w = 0;
+    int r = (d + (6 - w) + 7 -1)/7;
+
+    QString add = QString("%1-%2").arg(r).arg(w+1);
+    if (bFlag)
+    {
+        resetcalendardate(QString::number(date.day()));
+    }
+
+    map->value(add)->setToday();
+}
+
+void ChineseCalendar::showAbout()
+{
+    aboutDlg->show();
+}
+
+void ChineseCalendar::setAutoStart(bool bFlag)
+{
+    /* 设置是否开机自启动
+     * 当该目录下没有desktop文件时开机启动,有则不开机启动
+     * 因为系统安装时没有该用户目录,所以第一次是默认开机启动
+     */
+    if (!bFlag)
+    {
+        // 需要将desktop文件拷贝至~/.config/autostart目录下
+        QString strDesktop = "/usr/share/applications/chinese-calendar.desktop";
+        QString strCmd = "cp " + strDesktop + " ~/.local/share/chinese-calendar";
+        const char *cmd = strCmd.toUtf8().constData();
+        system(cmd);
+    }
+    else
+    {
+        QString filename = QDir::homePath() + "/.local/share/chinese-calendar/chinese-calendar.desktop";
+        QFile file(filename);
+
+        // if chinese-calendar.desktop is exist, then remove it.
+        if (file.exists())
+        {
+            file.remove();
+        }
+    }
+
+//    writeSetting();
+}
+
+bool ChineseCalendar::checkAutoStart()
+{
+    QString filename = QDir::homePath() + "/.local/share/chinese-calendar/chinese-calendar.desktop";
+    QFile file(filename);
+    if (file.exists())
+    {
+        return false;
+    }else{
+        return true;
+    }
+}
+
+void ChineseCalendar::readSetting()
+{
+    QSettings settings("chinese-calendar", "chinese-calendar");
+
+    settings.beginGroup("Config");
+
+    // 读取自启动标志
+    bool bAutoStart = this->checkAutoStart();
+//    bool bAutoStart = settings.value("autostart", false).toBool();
+
+    // 读取显示模式
+    m_nMode = settings.value("mode", 3).toInt();
+
+    // 读取皮肤名
+    m_skinName = settings.value("skin", "default").toString();
+
+    settings.endGroup();
+
+    actionAutoStart->setChecked(bAutoStart);
+
+    switch (m_nMode)
+    {
+    case 1:
+        actionStaysOnTop->setChecked(true);
+        actionStaysOnBottom->setChecked(false);
+        actionStaysNormal->setChecked(false);
+        break;
+    case 2:
+        actionStaysOnTop->setChecked(false);
+        actionStaysOnBottom->setChecked(true);
+        actionStaysNormal->setChecked(false);
+        break;
+    case 3:
+        actionStaysOnTop->setChecked(false);
+        actionStaysOnBottom->setChecked(false);
+        actionStaysNormal->setChecked(true);
+        break;
+    default:
+        ;
+    }
+
+    setMode(m_nMode, false);
+
+    if (m_skinName == "default" || m_skinName == "blue")
+    {
+        changeSkin(m_skinName);
+    }
+    else
+    {
+        changeSkin(m_skinName, false);
+    }
+    setCalendar();
+}
+
+void ChineseCalendar::writeSetting()
+{
+    QSettings settings("chinese-calendar", "chinese-calendar");
+
+    settings.beginGroup("Config");
+    settings.setValue("autostart", actionAutoStart->isChecked());
+    settings.setValue("mode", m_nMode);
+    settings.setValue("skin", m_skinName);
+
+    settings.endGroup();
+}
