@@ -7,13 +7,13 @@ Cnote::Cnote(QWidget *parent) :
 {
     setWindowFlags(Qt::FramelessWindowHint);
     setAttribute(Qt::WA_TranslucentBackground);
-    pix.load(":/img/note.png",0,Qt::AvoidDither|Qt::ThresholdDither|Qt::ThresholdAlphaDither);
+    //pix.load(":/img/note.png",0,Qt::AvoidDither|Qt::ThresholdDither|Qt::ThresholdAlphaDither);
     resize(224,280);
-    textedit = new QTextEdit(this);
-    ok = new QPushButton(this);
-    cancel = new QPushButton(this);
-    datelabel = new QLabel(this);
-    clearplan = new QPushButton(this);
+    textedit = new QTextEdit(this); textedit->setObjectName("textedit");
+    ok = new QPushButton(this); ok->setObjectName("ok");
+    cancel = new QPushButton(this);cancel->setObjectName("cancel");
+    datelabel = new QLabel(this);datelabel->setObjectName("datelabel");
+    clearplan = new QPushButton(this);clearplan->setObjectName("clearplan");
     textedit->resize(155,140);
     textedit->move(30,60);
     ok->resize(30,30);
@@ -26,13 +26,13 @@ Cnote::Cnote(QWidget *parent) :
     datelabel->resize(120,20);
     datelabel->move(50,40);
 
-    ok->setStyleSheet("QPushButton{background-color:transparent;}");
-    cancel->setStyleSheet("QPushButton{background-color:transparent;border:0 solid}");
-    datelabel->setStyleSheet("QLabel{background-color:transparent;border:0 solid;}");
-    clearplan->setStyleSheet("QPushButton{background-color:transparent;}");
-    ok->setIcon(QIcon(":/img/ok.png"));
-    cancel->setIcon(QIcon(":/img/no.png"));
-    textedit->setStyleSheet("QTextEdit{background-color:transparent;border:0 solid;}");
+    //ok->setStyleSheet("QPushButton{background-color:transparent;}");
+    //cancel->setStyleSheet("QPushButton{background-color:transparent;border:0 solid}");
+    //datelabel->setStyleSheet("QLabel{background-color:transparent;border:0 solid;}");
+    //clearplan->setStyleSheet("QPushButton{background-color:transparent;}");
+    //ok->setIcon(QIcon(":/img/ok.png"));
+    //cancel->setIcon(QIcon(":/img/no.png"));
+    //textedit->setStyleSheet("QTextEdit{background-color:transparent;border:0 solid;}");
     connect(this->ok,SIGNAL(clicked()),this,SLOT(savenote()));
     connect(this->cancel,SIGNAL(clicked()),this,SLOT(cancelnote()));
     connect(this->clearplan,SIGNAL(clicked()),this,SLOT(clean()));
@@ -66,7 +66,10 @@ void Cnote::cancelnote()
 void Cnote::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
-    painter.drawPixmap(0,0,pix.scaled(this->size(),Qt::IgnoreAspectRatio,Qt::SmoothTransformation));
+    //painter.drawPixmap(0,0,pix.scaled(this->size(),Qt::IgnoreAspectRatio,Qt::SmoothTransformation));
+    QStyleOption opt;
+    opt.init(this);
+    style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 }
 
 void  Cnote::mouseMoveEvent(QMouseEvent *event)
