@@ -25,6 +25,7 @@
 
 #include <QWidget>
 #include <QMouseEvent>
+#include "cnote.h"
 
 class DateMaskWidget : public QWidget
 {
@@ -33,9 +34,8 @@ public:
     explicit DateMaskWidget(QWidget *parent = 0);
     
 signals:
-    void entered();
-    void leaved();
     void clicked();
+    void clickday();
 
 protected:
     void mousePressEvent(QMouseEvent *ev);
